==> bewell_pro_core-1.1.4-nullsafety.tar.gz: lib/presentation/router/routes.dart <==
const String landingPageRoute = '/landing';

const String recoverPinRoute = '/recoverPin';

const String resetPinRoute = '/resetPin';

const String phoneSignupRoute = '/phoneSignup';

const String phoneLoginRoute = '/phoneLogin';

const String setPinRoute = '/setPin';

const String verifyPinResetRequestRoute = '/verifyPinResetRequest';

const String userNamesRoute = '/userNames';

const String pinVerificationRoute = '/pinVerification';

const String homePageRoute = '/home';

const String timelineRoute = '/timeline';

const String cameraRoute = '/camera';

const String imagePreviewRoute = '/imagePreview';

const String verifyPhoneRoute = '/verifyPhone';

const String verifyCodeRoute = '/verifyCode';

const String verifyEmailRoute = '/verifyEmail';

const String confirmSurveyRoute = '/confirmSurvey';

const String userProfileRoute = '/userProfile';

const String channelsPageRoute = '/channelsPage';

const String helpCenterRoute = '/helpCenter';

const String comingSoon = '/comingSoon';

const String proFeedItemThreadPageRoute = '/proFeedItemThreadPage';

const String webViewRoute = '/webView';

const String setPartnerPageRoute = '/setPartnerPage';

const String commSettingsRoute = '/commSettings';

const String editUserProfileRoute = '/edit_user_profile';

const String providerSearchPageRoute = '/providerSearchPage';

const String ediLoginPageRoute = '/ediLoginPage';

const String defaultBranchPickerPageRoute = '/defaultBranchPickerPage';

const String profileContactInfoRoute = '/profileContactInfo';

const String profileChangePinRoute = '/profileChangePin';

const String profileContactDetailsRoute = '/profileContactDetails';

const String tryNewFeatureSettingsRoute = '/tryNewFeatureSettings';

const String patientIdentificationRoute = '/searchFindPatient';

const String startVisitRoute = '/startVisitPage';

const String addPatientRoute = '/addPatient';

/// bottom navigation bar urls
const String patientsPageRoute = '/patients';

const String patientProfilePageRoute = '/patientProfile';

const String patientExamPageRoute = '/patientExamination';

const String patientExamSummaryPageRoute = '/patientExaminationSummary';

const String confirmSurveyPageRoute = '/confirmPostVisitSurvey';

const String postVisitSurveyPageRoute = '/postVisitSurvey';

==> bewell_pro_core-1.1.25-nullsafety.tar.gz: lib/presentation/router/routes.dart <==
const String landingPageRoute = '/landing';

const String recoverPinRoute = '/recoverPin';

const String resetPinRoute = '/resetPin';

const String phoneSignupRoute = '/phoneSignup';

const String phoneLoginRoute = '/phoneLogin';

const String setPinRoute = '/setPin';

const String verifyPinResetRequestRoute = '/verifyPinResetRequest';

const String userNamesRoute = '/userNames';

const String pinVerificationRoute = '/pinVerification';

const String homePageRoute = '/home';

const String timelineRoute = '/timeline';

const String cameraRoute = '/camera';

const String imagePreviewRoute = '/imagePreview';

const String verifyPhoneRoute = '/verifyPhone';

const String verifyCodeRoute = '/verifyCode';

const String verifyEmailRoute = '/verifyEmail';

const String confirmSurveyRoute = '/confirmSurvey';

const String userProfileRoute = '/userProfile';

const String channelsPageRoute = '/channelsPage';

const String helpCenterPageRoute = '/helpCenter';

const String comingSoon = '/comingSoon';

const String proFeedItemThreadPageRoute = '/proFeedItemThreadPage';

const String termsAndConditionsRoute = '/termsAndConditions';

const String setPartnerPageRoute = '/setPartnerPage';

const String communicationSettingsRoute = '/communicationSettings';

const String editUserProfileRoute = '/edit_user_profile';

const String providerSearchPageRoute = '/providerSearchPage';

const String defaultBranchPickerPageRoute = '/defaultBranchPickerPage';

const String profileContactInfoRoute = '/profileContactInfo';

const String profileChangePinRoute = '/profileChangePin';

const String profileContactDetailsRoute = '/profileContactDetails';

const String tryNewFeatureSettingsRoute = '/tryNewFeatureSettings';

const String patientIdentificationRoute = '/searchFindPatient';

const String startVisitPageRoute = '/startVisitPage';

const String addPatientRoute = '/addPatient';

/// bottom navigation bar urls
const String patientsPageRoute = '/patients';

const String patientProfilePageRoute = '/patientProfile';

const String patientExamPageRoute = '/patientExamination';

const String patientExamSummaryPageRoute = '/patientExaminationSummary';

const String confirmSurveyPageRoute = '/confirmPostVisitSurvey';

const String postVisitSurveyPageRoute = '/postVisitSurvey';
